@@ -211,7 +211,7 @@ groupInitDisplay (CompPlugin  *p,
 
     gd->textAvailable = checkPluginABI ("text", TEXT_ABIVERSION);
     if (!gd->textAvailable)
-	compLogMessage (d, "group", CompLogLevelWarn,
+	compLogMessage ("group", CompLogLevelWarn,
 			"No compatible text plugin loaded.");
 
     gd->glowTextureProperties =
@@ -346,7 +346,7 @@ groupInitScreen (CompPlugin *p,
 
     /* one-shot timeout for stuff that needs to be initialized after
        all screens and windows are initialized */
-    compAddTimeout (0, groupApplyInitialActions, (void *) s);
+    compAddTimeout (0, 0, groupApplyInitialActions, (void *) s);
 
     initTexture (s, &gs->glowTexture);
 
@@ -413,6 +413,9 @@ groupFiniScreen (CompPlugin *p,
     if (gs->tmpSel.windows)
 	free (gs->tmpSel.windows);
 
+    if (gs->grabIndex)
+	groupGrabScreen (s, ScreenGrabNone);
+
     freeWindowPrivateIndex (s, gs->windowPrivateIndex);
 
     UNWRAP (gs, s, windowMoveNotify);
